# Define: django_app::vhost
#
# Paremeters:
#
#   $docroot - the directory that contains wsgi.py file
#
#
# Examples:
#
#    include django_app
#    django_app::vhost { 'reptiles.lh':
#         docroot => '/some/dir'
#    }
#
#

define django_app::vhost (
  $docroot,
) {

    $project_name = inline_template('<%= @docroot.slice(/[^\/]+$/) -%>')
    $project_path = inline_template('<%= @docroot.sub(/\/[^\/]+$/, "") -%>')

    notify { "Project name: ${project_name}": }
    notify { "Project path: ${project_path}": }

    file_line { "/etc/hosts/${name}":
        path => '/etc/hosts',
        line => "127.0.0.1  ${name}",
    }

    apache::vhost { $name:
        port                        => '80',
        docroot                     => $docroot,
        wsgi_application_group      => '%{GLOBAL}',
        wsgi_daemon_process         => 'wsgi',
        wsgi_daemon_process_options => {
            python-path => $project_path
        },
        wsgi_import_script          => $project_path,
        wsgi_import_script_options  => {
            process-group     => 'wsgi',
            application-group => '%{GLOBAL}'
        },
        wsgi_process_group          => 'wsgi',
        wsgi_script_aliases         => {
            '/' => "${docroot}/wsgi.py"
        },
    }

}